@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '2.3'
-date = 'Wed Jun 26 12:44:59 2019'
+version = '2.4'
+date = 'Thu Oct 17 18:15:40 2019'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '2', '3', None)
+version_info = ('networkx', '2', '4', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2019, 6, 26, 12, 44, 59)
+date_info = datetime.datetime(2019, 10, 17, 18, 15, 40)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
